nbxmpp.tls_nb

Package nbxmpp :: Module tls_nb |
[hide private]
[frames] | no frames]

# Module tls_nb

source code

Classes | [hide private]
| SSLWrapper Abstract SSLWrapper base class
| PyOpenSSLWrapper Wrapper class for PyOpenSSL's recv() and send() methods
| StdlibSSLWrapper Wrapper class for Python socket.ssl read() and write() methods
| NonBlockingTLS TLS connection used to encrypts already estabilished tcp connection

Functions | [hide private]
gattr(obj, attr, default=None) | source code

Variables | [hide private]
| log = `logging.getLogger('nbxmpp.tls_nb')`
| PYOPENSSL = ``'``PYOPENSSL``'``
| PYSTDLIB = ``'``PYSTDLIB``'``
| USE_PYOPENSSL = `True`
| __package__ = ``'``nbxmpp``'``

Imports: socket, PlugIn, sys, os, time, traceback, logging, OpenSSL

Function Details | [hide private]

### gattr(obj, attr, default=None) | source code

Variables Details | [hide private]

  ### log Value:
      logging.getLogger('nbxmpp.tls_nb')

  ### PYOPENSSL Value:
      'PYOPENSSL'

  ### PYSTDLIB Value:
      'PYSTDLIB'

  ### USE_PYOPENSSL Value:
      True

  ### __package__ Value:
      'nbxmpp'